@@ -1,6 +1,6 @@
 // MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: char_property.cpp 77 2007-02-05 14:37:50Z taku-ku $;
+//  $Id: char_property.cpp 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -115,22 +115,7 @@ namespace MeCab {
 
   // this function must be rewritten.
   void CharProperty::set_charset(const char *ct) {
-    std::string tmp = ct;
-    toLower(&tmp);
-    if (tmp == "sjis"  || tmp == "shift-jis" ||
-        tmp == "shift_jis" || tmp == "cp932")
-      charset_ = CP932;
-    else if (tmp == "euc"   || tmp == "euc_jp" ||
-             tmp == "euc-jp")
-      charset_ = EUC_JP;
-    else if (tmp == "utf8" || tmp == "utf_8" ||
-             tmp == "utf-8")
-      charset_ = UTF8;
-    else if (tmp == "ascii")
-      charset_ = ASCII;
-    else
-      charset_ = UTF8;  // default is UTF8
-
+    charset_ = decode_charset(ct);
   }
 
   int CharProperty::id(const char *key) const {
