@@ -1,6 +1,6 @@
 // MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: common.h 93 2007-02-24 14:21:11Z taku-ku $;
+//  $Id: common.h 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -22,7 +22,7 @@
 #endif
 
 // tricky macro for MSVC
-#ifdef _MSC_VER
+#if defined(_MSC_VER) || defined(__CYGWIN__)
 #define for if (0); else for
 /* why windows.h define such a generic macro */
 #undef max
