@@ -1,11 +1,12 @@
 // MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: context_id.cpp 80 2007-02-06 01:52:25Z taku-ku $;
+//  $Id: context_id.cpp 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
 #include <fstream>
 #include "context_id.h"
+#include "iconv_utils.h"
 #include "utils.h"
 
 namespace {
@@ -13,15 +14,18 @@ namespace {
   using namespace MeCab;
 
   bool open(const char *filename,
-            std::map<std::string, int> *cmap) {
+            std::map<std::string, int> *cmap,
+            Iconv *iconv) {
     std::ifstream ifs(filename);
     CHECK_DIE(ifs) << "no such file or directory: " << filename;
     cmap->clear();
-    char buf[BUF_SIZE];
     char *col[2];
-    while (ifs.getline(buf, sizeof(buf))) {
-      CHECK_DIE(2 == tokenize2(buf, " \t", col, 2))
-        << "format error: " << buf;
+    std::string line;
+    while (std::getline(ifs, line)) {
+      if (iconv) iconv->convert(&line);
+      CHECK_DIE(2 == tokenize2(const_cast<char *>(line.c_str()),
+                               " \t", col, 2))
+        << "format error: " << line;
       cmap->insert(std::make_pair<std::string, int>
                    (col[1], std::atoi(col[0])));
     }
@@ -75,8 +79,10 @@ namespace MeCab {
   }
 
   bool ContextID::open(const char *lfile,
-                       const char *rfile) {
-    return(::open(lfile, &left_) && ::open(rfile, &right_));
+                       const char *rfile,
+                       Iconv *iconv) {
+    return(::open(lfile, &left_, iconv) &&
+           ::open(rfile, &right_, iconv));
   }
 
   bool ContextID::build() {
