@@ -1,6 +1,6 @@
 //  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: dictionary.h 117 2007-03-06 17:40:37Z taku-ku $;
+//  $Id: dictionary.h 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -10,6 +10,7 @@
 #include "mecab.h"
 #include "darts.h"
 #include "token.h"
+#include "char_property.h"
 
 namespace MeCab {
 
@@ -53,7 +54,8 @@ namespace MeCab {
       return(version_ == d.version_ &&
              lsize_  == d.lsize_   &&
              rsize_  == d.rsize_   &&
-             std::strcmp(charset_, d.charset_) == 0);
+             decode_charset(charset_) ==
+             decode_charset(d.charset_));
     }
 
     const char *filename() const { return filename_.c_str(); }
