@@ -1,5 +1,5 @@
 //  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
-//  $Id: dictionary_compiler.cpp 108 2007-03-05 15:48:45Z taku-ku $;
+//  $Id: dictionary_compiler.cpp 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -24,21 +24,23 @@ namespace MeCab {
   public:
     static int run(int argc, char **argv) {
       static const MeCab::Option long_options[] = {
-        { "dicdir",   'd',   ".",   "DIR", "set DIR as dicdir(default \".\")" },
-        { "outdir",   'o',   ".",   "DIR", "set DIR as output dir" },
+        { "dicdir",   'd',   ".",   "DIR", "set DIR as dicdi (default \".\")" },
+        { "outdir",   'o',   ".",   "DIR", "set DIR as output dir (default \".\")" },
         { "unknown",  'U',   0,   0,   "build parameters for unknown words" },
         { "userdic",  'u',   0,   "FILE",   "build user dictionary" },
         { "charcategory", 'C', 0, 0,   "build character category maps" },
         { "matrix",    'm',  0,   0,   "build connection matrix" },
         { "charset",   'c',  MECAB_DEFAULT_CHARSET, "ENC",
-          "dictionary charset(default " MECAB_DEFAULT_CHARSET ")"  },
+          "make charset of binary dictionary ENC (default " MECAB_DEFAULT_CHARSET ")"  },
         { "charset",   't',  MECAB_DEFAULT_CHARSET, "ENC", "alias of -c"  },
-        { "dcharset",  'f',  MECAB_DEFAULT_CHARSET,
-          "ENC", "assume input dictionary charset as ENC(default "
+        { "dictionary-charset",  'f',  MECAB_DEFAULT_CHARSET,
+          "ENC", "assume charset of input CSVs as ENC (default "
           MECAB_DEFAULT_CHARSET ")"  },
         { "wakati",    'w',  0,   0,   "build wakati-gaki only dictionary", },
+        // keep it for backward compatibility
         { "posid",     'p',  0,   0,   "assign Part-of-speech id" },
-        { "node-format", 'F', 0,  "STR",   "use STR as the user defined node format" },
+        { "node-format", 'F', 0,  "STR",
+          "use STR as the user defined node format" },
         { "version",   'v',  0,   0,   "show the version and exit."  },
         { "help",      'h',  0,   0,   "show this help and exit."  },
         { 0, 0, 0, 0 }
