@@ -1,6 +1,6 @@
 //  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: dictionary_rewriter.cpp 82 2007-02-11 15:15:19Z taku-ku $;
+//  $Id: dictionary_rewriter.cpp 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -13,6 +13,7 @@
 #include "utils.h"
 #include "common.h"
 #include "dictionary_rewriter.h"
+#include "iconv_utils.h"
 
 namespace {
 
@@ -204,26 +205,28 @@ namespace MeCab {
 
   void DictionaryRewriter::clear() { cache_.clear(); }
 
-  bool DictionaryRewriter::open(const char *filename) {
+  bool DictionaryRewriter::open(const char *filename,
+                                Iconv *iconv) {
     std::ifstream ifs(filename);
     CHECK_DIE(ifs) << "no such file or directory: " << filename;
-    char line[BUF_SIZE];
-    std::string line2;
     int append_to = 0;
-    while (ifs.getline(line, sizeof(line))) {
-      if (std::strlen(line) == 0 || line[0] == '#') continue;
-      if (std::strcmp(line, "[unigram rewrite]") == 0) {
+    std::string line;
+    while (std::getline(ifs, line)) {
+      if (iconv) iconv->convert(&line);
+      if (line.empty() || line[0] == '#') continue;
+      if (line == "[unigram rewrite]") {
         append_to = 1;
-      } else if (std::strcmp(line, "[left rewrite]") == 0) {
+      } else if (line == "[left rewrite]") {
         append_to = 2;
-      } else if (std::strcmp(line, "[right rewrite]") == 0) {
+      } else if (line == "[right rewrite]") {
         append_to = 3;
       } else {
         CHECK_DIE(append_to != 0) << "no sections found";
+        char *str = const_cast<char *>(line.c_str());
         switch (append_to) {
-        case 1: append_rewrite_rule(&unigram_rewrite_, line); break;
-        case 2: append_rewrite_rule(&left_rewrite_,    line); break;
-        case 3: append_rewrite_rule(&right_rewrite_,   line); break;
+        case 1: append_rewrite_rule(&unigram_rewrite_, str); break;
+        case 2: append_rewrite_rule(&left_rewrite_,    str); break;
+        case 3: append_rewrite_rule(&right_rewrite_,   str); break;
         }
       }
     }
@@ -271,13 +274,23 @@ namespace MeCab {
     return true;
   }
 
-  bool POSIDGenerator::open(const char *filename) {
+  bool POSIDGenerator::open(const char *filename,
+                            Iconv *iconv) {
     std::ifstream ifs(filename);
-    CHECK_DIE(ifs) << "no such file or directory: " << filename;
-    char line[BUF_SIZE];
-    while (ifs.getline(line, sizeof(line))) {
-      char *col[2];
-      size_t n = tokenize2(line, " \t", col, 2);
+    if (!ifs) {
+      std::cerr << filename
+                << " is not found. minimum setting is used" << std::endl;
+      rewrite_.resize(1);
+      rewrite_.back().set_pattern("*", "1");
+      return true;
+    }
+
+    std::string line;
+    char *col[2];
+    while (std::getline(ifs, line)) {
+      if (iconv) iconv->convert(&line);
+      size_t n = tokenize2(const_cast<char *>(line.c_str()),
+                           " \t", col, 2);
       CHECK_DIE(n == 2) << "format error: " << line;
       for (char *p = col[1]; *p; ++p) {
         CHECK_DIE(*p >= '0' && *p <= '9') << "not a number: " << col[1];
