@@ -1,12 +1,9 @@
-/*
-  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
-
-  $Id: lbfgs.h,v 1.8 2006/07/09 11:26:27 taku-ku Exp $;
-
-  Copyright (C) 2001-2006 Taku Kudo <taku@chasen.org>
-  Copyright (C) 2004-2006 Nippon Telegraph and Telephone Corporation
-
-*/
+//  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+//
+//  $Id: lbfgs.h 64 2007-01-30 00:51:51Z taku-ku $;
+//
+//  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
+//  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
 #ifndef MECAB_LBFGS_H
 #define MECAB_LBFGS_H
 
@@ -22,26 +19,25 @@ extern "C" {
 namespace MeCab {
 
   class LBFGS {
-
   private:
-    int n_;
-    int m_;
-    int iflag_;
-    whatlog what_;
-    std::vector <double> diag_;
-    std::vector <double> w_;
+    int                 n_;
+    int                 m_;
+    int                 iflag_;
+    whatlog             what_;
+    std::vector<double> diag_;
+    std::vector<double> w_;
 
   public:
-    explicit LBFGS(): n_(0), m_(5), iflag_(0) {};
-    virtual ~LBFGS() {};
+    explicit LBFGS(): n_(0), m_(5), iflag_(0) {}
+    virtual ~LBFGS() {}
 
     const char *what() { return what_.str(); }
 
     int init(int _n, int _m) {
       n_ = _n;
       m_ = _m;
-      w_.resize (n_ * (2 * m_ + 1) + 2 * m_);
-      diag_.resize (n_);
+      w_.resize(n_ *(2 * m_ + 1) + 2 * m_);
+      diag_.resize(n_);
       return 0;
     }
 
@@ -50,16 +46,18 @@ namespace MeCab {
       double eta  = 1e-7;
       double xtol = 1e-7;
       int diagco = 0;
-      lbfgs(&n_, &m_, x, f, g, &diagco, &diag_[0], iprint, &eta, &xtol, &w_[0], &iflag_);
+      lbfgs(&n_, &m_, x, f, g, &diagco, &diag_[0],
+            iprint, &eta, &xtol, &w_[0], &iflag_);
 
       if (iflag_ < 0) {
         CHECK_FALSE(false) << "routine stops with unexpected error";
         return -1;
       }
 
-      if (iflag_ == 0) return 0; // terminate
+      if (iflag_ == 0)
+        return 0;  // terminate
 
-      return 1; // evaluate next f and g
+      return 1;  // evaluate next f and g
     }
   };
 }
