@@ -1,6 +1,6 @@
 //  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//  $Id: learner.cpp 108 2007-03-05 15:48:45Z taku-ku $;
+//  $Id: learner.cpp 126 2007-06-07 03:04:29Z taku-ku $;
 //
 //  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -31,7 +31,7 @@ namespace MeCab {
       DictionaryRewriter rewrite;
 
 #define DCONF(file) create_filename(dicdir, std::string(file)).c_str()
-      std::string dicdir = param->get<std::string>("dicdir");
+      const std::string dicdir = param->get<std::string>("dicdir");
       CHECK_DIE(param->load(DCONF(DICRC)))
         << "no such file or directory: " << DCONF(DICRC);
 
@@ -39,18 +39,19 @@ namespace MeCab {
         << "no such file or directory: " << DCONF(REWRITE_FILE);
 #undef DCONF
 
-      std::vector<std::string> files = param->rest_args();
+      const std::vector<std::string> files = param->rest_args();
       if (files.size() != 2) {
         std::cout << "Usage: " <<
           param->program_name() << " corpus model" << std::endl;
         return -1;
       }
 
-      std::string ifile = files[0];
-      std::string model = files[1];
+      const std::string ifile = files[0];
+      const std::string model = files[1];
 
       bool text_only = param->get<bool>("text-only");
-      std::string bos_feature = param->get<std::string>("bos-feature");
+      bool em_hmm = param->get<bool>("em-hmm");
+      const std::string bos_feature = param->get<std::string>("bos-feature");
 
       CHECK_DIE(!bos_feature.empty()) << "bos-feature is empty";
 
@@ -63,7 +64,55 @@ namespace MeCab {
       std::map<std::string, std::map<std::string, double> > transition;
 
       // corpus
-      {
+      if (em_hmm) {
+        std::ifstream ifs(ifile.c_str());
+        CHECK_DIE(ifs) << "no such file or directory: " << ifile;
+        size_t size = 0;
+        while (ifs.getline(line, sizeof(line))) {
+          if (std::strcmp("EOS", line) == 0) {
+            if (++size % 100 == 0)
+              std::cout << size << "... " << std::flush;
+            continue;
+          }
+
+          CHECK_DIE(tokenize(line, "\t", col, 4) == 4)
+            << "format error\n";
+          CHECK_DIE(std::strcmp("B", col[0]) == 0 &&
+                    std::strcmp("U", col[0]) == 0)
+                      << "format error\n";
+          if (col[0][0] == 'B') { // bigram
+            feature = col[1];
+            CHECK_DIE(rewrite.rewrite(feature,
+                                      &ufeature,
+                                      &lfeature,
+                                      &rfeature))
+                                        << "rewrite failed";
+            prfeature = rfeature;
+            feature = col[2];
+            CHECK_DIE(rewrite.rewrite(feature,
+                                      &ufeature,
+                                      &lfeature,
+                                      &rfeature))
+                                        << "rewrite failed";
+            plfeature = lfeature;
+            transition[prfeature][plfeature] += std::atof(col[3]);
+          } else {   // unigram
+            feature = col[2];
+            CHECK_DIE(rewrite.rewrite(feature,
+                                      &ufeature,
+                                      &lfeature,
+                                      &rfeature))
+                                        << "rewrite failed";
+            std::strncpy(line, ufeature.c_str(), sizeof(line));
+            size_t n = tokenize2(line, "\t ", col, 2);
+            CHECK_DIE(n == 2) << "format error in rewrite.def: " << ufeature;
+            ufeature = col[0];
+            word = col[1];
+            emission[ufeature][word] += atof(col[3]);
+          }
+          ++size;
+        }
+      } else {
         std::ifstream ifs(ifile.c_str());
         CHECK_DIE(ifs) << "no such file or directory: " << ifile;
 
@@ -92,7 +141,7 @@ namespace MeCab {
 
           std::strncpy(line, ufeature.c_str(), sizeof(line));
           // unigram rule must contain ' '
-          size_t n = tokenize2(line, "\t ", col, 2);
+          const size_t n = tokenize2(line, "\t ", col, 2);
           CHECK_DIE(n == 2) << "format error in rewrite.def: " << ufeature;
           ufeature = col[0];
           word = col[1];
@@ -112,7 +161,7 @@ namespace MeCab {
         CHECK_DIE(freq >= 0.0) << " default-emission-freq must be >= 0 "
                                << freq;
 
-        for (std::vector<std::string>::iterator it = dic.begin();
+        for (std::vector<std::string>::const_iterator it = dic.begin();
              it != dic.end(); ++it) {
           std::cout << "reading " << *it << " ... " << std::flush;
 
@@ -127,7 +176,7 @@ namespace MeCab {
                                       &lfeature,
                                       &rfeature)) << "rewrite failed";
             std::strncpy(line, ufeature.c_str(), sizeof(line));
-            size_t n = tokenize2(line, "\t ", col, 2);
+            const size_t n = tokenize2(line, "\t ", col, 2);
             CHECK_DIE(n == 2) << "format error: " << ufeature;
             ufeature = col[0];
             word = col[1];
@@ -150,31 +199,31 @@ namespace MeCab {
         ofs.precision(24);
 
         // bigram
-        for (std::map<std::string, std::map<std::string, double> >::iterator
+        for (std::map<std::string, std::map<std::string, double> >::const_iterator
                it = transition.begin();
              it != transition.end(); ++it) {
           double freq = 0.0;
-          for (std::map<std::string, double>::iterator it2 = it->second.begin();
+          for (std::map<std::string, double>::const_iterator it2 = it->second.begin();
                it2 != it->second.end(); ++it2) {
             freq += it2->second;
           }
 
-          for (std::map<std::string, double>::iterator it2 = it->second.begin();
+          for (std::map<std::string, double>::const_iterator it2 = it->second.begin();
                it2 != it->second.end(); ++it2)
             ofs << toLogProb(it2->second, freq) << '\t'
                 << 'B' << ':' << it->first << '/' << it2->first << std::endl;
         }
 
         // unigram
-        for (std::map<std::string, std::map<std::string, double> >::iterator
+        for (std::map<std::string, std::map<std::string, double> >::const_iterator
                it = emission.begin();
              it != emission.end(); ++it) {
           double freq = 0.0;
-          for (std::map<std::string, double>::iterator it2 = it->second.begin();
+          for (std::map<std::string, double>::const_iterator it2 = it->second.begin();
                it2 != it->second.end(); ++it2)
             freq += it2->second;
 
-          for (std::map<std::string, double>::iterator it2 = it->second.begin();
+          for (std::map<std::string, double>::const_iterator it2 = it->second.begin();
                it2 != it->second.end(); ++it2) {
             std::string w = it2->first;
             CHECK_DIE(escape_csv_element(&w));
@@ -227,7 +276,7 @@ namespace MeCab {
   public:
     static int run(Param *param) {
 #define DCONF(file) create_filename(dicdir, std::string(file)).c_str()
-      std::string dicdir = param->get<std::string>("dicdir");
+      const std::string dicdir = param->get<std::string>("dicdir");
       CHECK_DIE(param->load(DCONF(DICRC)))
         << "no such file or directory: " << DCONF(DICRC);
 
@@ -240,8 +289,8 @@ namespace MeCab {
         return -1;
       }
 
-      std::string ifile = files[0];
-      std::string model = files[1];
+      const std::string ifile = files[0];
+      const std::string model = files[1];
 
       double C = param->get<double>("cost");
       double eta = param->get<double>("eta");
@@ -433,6 +482,7 @@ namespace MeCab {
           "set FLOAT for cost C for constraints violatoin" },
         { "training-algorithm",   'a',  "crf",
           "(crf|hmm)", "set training algorithm" },
+        { "em-hmm", 'E', 0, 0,       "use EM in HMM training (experimental)" },
         { "freq",     'f',  "1",     "INT",
           "set the frequency cut-off (default 1)" },
         { "default-emission-freq", 'E',  "0.5",     "FLOAT",
@@ -463,14 +513,14 @@ namespace MeCab {
       {
         bool build = param.get<bool>("build");
         if (build) {
-          std::vector<std::string> files = param.rest_args();
+          const std::vector<std::string> files = param.rest_args();
           if (files.size() != 2) {
             std::cout << "Usage: " <<
               param.program_name() << " corpus model" << std::endl;
             return -1;
           }
-          std::string ifile = files[0];
-          std::string model = files[1];
+          const std::string ifile = files[0];
+          const std::string model = files[1];
           EncoderFeatureIndex feature_index;
           CHECK_DIE(feature_index.convert(ifile.c_str(), model.c_str()))
             << feature_index.what();
