@@ -1,6 +1,6 @@
 //   MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
 //
-//   $Id: utils.h 92 2007-02-24 14:03:08Z taku-ku $;
+//   $Id: utils.h 131 2007-06-09 16:18:15Z taku-ku $;
 //
 //   Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
 //   Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
@@ -25,6 +25,9 @@ namespace MeCab {
   template <class T> inline T _max(T x, T y) { return(x > y) ? x : y; }
 
   class Param;
+
+  enum { EUC_JP, CP932, UTF8, ASCII };
+  int decode_charset(const char *charset);
   
   void inline dtoa(double val, char *s) {
     std::sprintf(s, "%-16f", val);
