@@ -1,12 +1,9 @@
-/*
-  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
-
-  $Id: viterbisub.h,v 1.6 2006/07/09 11:26:27 taku-ku Exp $;
-
-  Copyright (C) 2001-2006 Taku Kudo <taku@chasen.org>
-  Copyright (C) 2004-2006 Nippon Telegraph and Telephone Corporation
-
-*/
+//  MeCab -- Yet Another Part-of-Speech and Morphological Analyzer
+//
+//  $Id: viterbisub.h 64 2007-01-30 00:51:51Z taku-ku $;
+//
+//  Copyright(C) 2001-2006 Taku Kudo <taku@chasen.org>
+//  Copyright(C) 2004-2006 Nippon Telegraph and Telephone Corporation
 #include "viterbi.h"
 
 // for MSVC
@@ -15,25 +12,21 @@
 namespace MeCab {
 
 #ifdef _VITERBI_WITH_ALL_PATH
-  bool Viterbi::connectWithAllPath
+  bool Viterbi::connectWithAllPath(size_t pos, Node *rNode) {
 #else
-  bool Viterbi::connectNormal
+  bool Viterbi::connectNormal(size_t pos, Node *rNode) {
 #endif
-  (size_t pos, Node *rNode)
-  {
     for (;rNode; rNode = rNode->bnext) {
-
       register long bestCost = 2147483647;
 
       Node* bestNode = 0;
 
       for (Node *lNode = end_node_list_[pos]; lNode; lNode = lNode->enext) {
-
 #ifdef _VITERBI_WITH_ALL_PATH
-        register int lcost = connector_->getCost (lNode, rNode); // local cost
+        register int  lcost = connector_->getCost(lNode, rNode);  // local cost
         register long cost  = lNode->cost + lcost;
 #else
-        register long cost  = lNode->cost + connector_->getCost (lNode, rNode);
+        register long cost  = lNode->cost + connector_->getCost(lNode, rNode);
 #endif
 
         if (cost < bestCost) {
@@ -42,7 +35,7 @@ namespace MeCab {
         }
 
 #ifdef _VITERBI_WITH_ALL_PATH
-        Path *path   = path_freelist_->alloc ();
+        Path *path   = path_freelist_->alloc();
         path->cost   = lcost;
         path->rnode  = rNode;
         path->lnode  = lNode;
